<?php

/**
 * Helper functions to handle uc_cc_fee variables
 */
function _uc_cc_fee_get_var_name($name) {
  return "uc_cc_fee_var_{$name}_fee";
}

function uc_cc_fee_get_all_vars_names() {
  global $conf;

  return preg_grep("/^uc_cc_fee_var_[a-z0-9_]+_fee$/", array_keys($conf));
}

function _uc_cc_fee_get_operations($fee_id) {
  $edit = l('edit', 'admin/store/settings/cc_fee/edit/'. $fee_id);
  $delete = l('delete', 'admin/store/settings/cc_fee/delete/'. $fee_id);

  return "{$edit} | {$delete}";
}

/**
 * Helper method. If credit method is activated and only payment method in
 * checkout.
 */
function _uc_cc_fee_is_credit_method() {
    $methods = array_filter(_payment_method_list(), '_uc_cc_fee_filter_credit');

    // Set (overwrite) array keys from 0 forward
    sort($methods);

    // If method is 'credit' and is the ONLY method
    if (count($methods) == 1 && $methods[0]['id'] == 'credit') {
      return 1;
    } else {
      return 0;
    }
}

/**
 * Helper function. Return only enabled payment methods.
 */
function _uc_cc_fee_filter_credit($method) {
  return $method['checkout'] === 1 ? 1 : 0;
}

/**
 * Prepare all fees data in one array and return it.
 *
 * @return array of fees data
 */
function uc_cc_fee_cards_data() {
  $fees = array();
  foreach(uc_cc_fee_get_all_vars_names() as $fee_full_id) {
    $fee_id = _uc_cc_fee_real_id($fee_full_id);
    $fees[$fee_id] = variable_get($fee_full_id, ''); // set fee data
  }

  // Sort fees by 'weight'. This is the way how to recreate saved order in drag
  // & drop table rows.
  uasort($fees, '_uc_cc_fee_weight_comparation');

  return $fees;
}

/**
 * Helper function.
 *
 * @see uc_cc_fee_cards_data()
 */
function _uc_cc_fee_weight_comparation(array $a, array $b) {
  return $a['weight'] - $b['weight'];
}

/**
 * Helper function get full-real fee ID.
 */
function _uc_cc_fee_real_id($fee_full_id) {
  return preg_replace('/^uc_cc_fee_var_(\w+)_fee$/i', '$1', $fee_full_id);
}

/**
 * Helper function to load fee data. Used in menu /%fee_name.
 *
 * @return
 *   If variable exist returning full object with full variable name in it, NULL
 *   otherwise
 */
function uc_cc_fee_load($fee_name) {
  $fee_full_name = _uc_cc_fee_get_var_name($fee_name);
  $fee = variable_get($fee_full_name, NULL);
  if ($fee != NULL) {
    $fee['var_name'] = $fee_full_name;
    return (object) $fee;
  } else {
    return NULL;
  }
}

/**
 * Helper function to format price if it's not percentage.
 *
 * @param Fee value
 *
 * @return Formatted fee value
 */
function uc_cc_fee_format_value($value) {
  return _uc_cc_fee_percentage($value) ? $value : uc_currency_format($value);
}

/**
 * Helper function. Check if last character of string is '%'.
 *
 * @param $string - string to check
 *
 * @return True if last char is '%', false otherwise.
 */
function _uc_cc_fee_percentage($string) {
  return substr($string, -1) == '%' ? TRUE : FALSE;
}

/**
 * Calculate credit card fee amount to be paid
 *
 * @param $fee_name basic fee name
 * @param $subtotal subtotal
 *
 * @return If fee is founded then returing row fee amount (value) or calculated
 * percentage amount based on subtotal amount. Otherwise NULL is returned.
 */
function uc_cc_fee_amount(&$order) {
  if ($fee = uc_cc_fee_load($order->data['cc_fee'])) {
    // If percentage value..
    if (_uc_cc_fee_percentage($fee->value)) {
      // .. calculate percentage fee based on subtotal value
      // $subtotal * $percentage
      return uc_order_get_total($order, TRUE) * (rtrim($fee->value, '%') / 100);

    // .. just return fee value
    } else {
      return $fee->value;
    }
  } else {
    return NULL;
  }
}
